@@ -620,7 +620,9 @@ fil["617"]= "nvrtc/index.html@@@NVRTC (Runtime Compilation) :: CUDA Toolkit Docu
 fil["618"]= "nvvm-ir-spec/index.html@@@NVVM IR :: CUDA Toolkit Documentation@@@Reference guide to the NVVM compiler IR (internal representation) based on the LVVM IR...";
 fil["619"]= "optimus-developer-guide/index.html@@@Developer Guide for Optimus :: CUDA Toolkit Documentation@@@The API reference guide for GPU querying of Optimus systems...";
 fil["620"]= "parallel-thread-execution/index.html@@@PTX ISA :: CUDA Toolkit Documentation@@@The programming guide to using PTX (Parallel Thread Execution) and ISA (Instruction Set Architecture...";
-fil["621"]= "profiler-users-guide/index.html@@@Profiler :: CUDA Toolkit Documentation@@@The user manual for NVIDIA profiling tools for optimizing performance of CUDA applications...";
-fil["622"]= "ptx-writers-guide-to-interoperability/index.html@@@PTX Interoperability :: CUDA Toolkit Documentation@@@The guide to writing ABI-compliant PTX...";
-fil["623"]= "thrust/index.html@@@Thrust :: CUDA Toolkit Documentation@@@The API reference guide for Thrust, the CUDA C++ template library...";
-fil["624"]= "video-decoder/index.html@@@Video Decoder :: CUDA Toolkit Documentation@@@The API reference guide for the CUDA video decoder...";
+fil["621"]= "pascal-compatibility-guide/index.html@@@Pascal Compatibility Guide :: CUDA Toolkit Documentation@@@The guide to building CUDA applications for GPUs based on the NVIDIA Pascal Architecture...";
+fil["622"]= "pascal-tuning-guide/index.html@@@Pascal Tuning Guide :: CUDA Toolkit Documentation@@@The programming guide to tuning CUDA Applications for GPUs based on the NVIDIA Pascal Architecture...";
+fil["623"]= "profiler-users-guide/index.html@@@Profiler :: CUDA Toolkit Documentation@@@The user manual for NVIDIA profiling tools for optimizing performance of CUDA applications...";
+fil["624"]= "ptx-writers-guide-to-interoperability/index.html@@@PTX Interoperability :: CUDA Toolkit Documentation@@@The guide to writing ABI-compliant PTX...";
+fil["625"]= "thrust/index.html@@@Thrust :: CUDA Toolkit Documentation@@@The API reference guide for Thrust, the CUDA C++ template library...";
+fil["626"]= "video-decoder/index.html@@@Video Decoder :: CUDA Toolkit Documentation@@@The API reference guide for the CUDA video decoder...";
