@@ -621,8 +621,10 @@ fl["617"]= "nvrtc/index.html";
 fl["618"]= "nvvm-ir-spec/index.html";
 fl["619"]= "optimus-developer-guide/index.html";
 fl["620"]= "parallel-thread-execution/index.html";
-fl["621"]= "profiler-users-guide/index.html";
-fl["622"]= "ptx-writers-guide-to-interoperability/index.html";
-fl["623"]= "thrust/index.html";
-fl["624"]= "video-decoder/index.html";
+fl["621"]= "pascal-compatibility-guide/index.html";
+fl["622"]= "pascal-tuning-guide/index.html";
+fl["623"]= "profiler-users-guide/index.html";
+fl["624"]= "ptx-writers-guide-to-interoperability/index.html";
+fl["625"]= "thrust/index.html";
+fl["626"]= "video-decoder/index.html";
 var doStem = true
\ No newline at end of file
