@@ -52,10 +52,10 @@
 
 #if !defined(__CUDACC_RTC__)
 #if defined(__GNUC__)
-#if defined(__clang__) || (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
+#if defined(__clang__) || (!defined(__PGIC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)))
 #pragma GCC diagnostic push
 #endif
-#if defined(__clang__) || (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 2))
+#if defined(__clang__) || (!defined(__PGIC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 2)))
 #pragma GCC diagnostic ignored "-Wunused-function"
 #endif
 #elif defined(_MSC_VER)
@@ -1926,7 +1926,7 @@ static __inline__ __host__ cudaError_t cudaBindSurfaceToArray(
 
 #if !defined(__CUDACC_RTC__)
 #if defined(__GNUC__)
-#if defined(__clang__) || (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
+#if defined(__clang__) || (!defined(__PGIC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)))
 #pragma GCC diagnostic pop
 #endif
 #elif defined(_MSC_VER)
